import request, { postBlob, getBlob, handleImport } from '@/utils/request'

export function noticeWebsitList(data) {
  return request({
    url: `/noticeWebsit/list?moduleId=${data.moduleId}`,
    method: 'post',
    data
  })
}

export function noticeWebsitListExport(data, name) {
  return postBlob({
    url: '/noticeWebsit/list/export',
    data,
    name
  })
}

export function noticeWebsitAdd(data) {
  return request({
    url: `/noticeWebsit/add`,
    method: 'post',
    data
  })
}

export function noticeWebsitUpdate(data) {
  return request({
    url: `/noticeWebsit/update`,
    method: 'post',
    data
  })
}

export function noticeWebsitDetail(params) {
  return request({
    url: `/noticeWebsit/detail`,
    method: 'get',
    params
  })
}

export function noticeWebsitOfOrSend(params) {
  return request({
    url: `/noticeWebsit/ofOrSend`,
    method: 'post',
    params
  })
}

export function noticeWebsitListWebsit(data) {
  return request({
    url: `/noticeWebsit/listWebsit?moduleId=${data.moduleId}`,
    method: 'post',
    data
  })
}

export function noticeWebsitListWebsitExport(data, name) {
  return postBlob({
    url: '/noticeWebsit/listWebsit/export',
    data,
    name
  })
}

export function noticeWebsitMarkRead(params) {
  return request({
    url: `/noticeWebsit/mark/read`,
    method: 'post',
    params
  })
}

export function noticeWebsitMarkReadOne(params) {
  return request({
    url: `/noticeWebsit/mark/readOne`,
    method: 'post',
    params
  })
}
